
---------------------------------------------------
-- [v1.01.00] Make sure we have nUI tables
---------------------------------------------------
if not nUI_InfoPanels then nUI_InfoPanels = {}; end

----------------------------------------------------------------
-- [v1.01.00] Localized Functions and Tables to speed things up
----------------------------------------------------------------
local _L = nUI_InfoPanel_SmartDebuff_L;

---------------------------------------------------
-- [v1.01.00] Allocation of the Window ID (unique)
---------------------------------------------------
nUI_INFOMODE_SMARTDEBUFF  = 24;
nUI_INFOPANEL_SMARTDEBUFF = "nUI_InfoPanel_SmartDebuff";

---------------------------------------------------
-- [v1.01.00] Some Constants
---------------------------------------------------

---------------------------------------------------
-- [v1.01.00] Set the Default values for the Infopanel
---------------------------------------------------
nUI_InfoPanels[nUI_INFOPANEL_SMARTDEBUFF ] =
{	
	enabled   = true,
	desc      = _L["Info Panel Text"],             -- player friendly name/description of the panel
	label     = _L["Info Panel Label"],	       -- label to use on the panel selection button face
	rotation  = nUI_INFOMODE_SMARTDEBUFF,            -- index or position this panel appears on/in when clicking the selector button
	full_size = true;                              -- this plugin requires the entire info panel port without the button bag
	
	options  =
	{
		enabled  = true,
	},
};

---------------------------------------------------
-- [v1.01.00] Set Plugin Values
---------------------------------------------------
local plugin    = CreateFrame( "Frame", nUI_INFOPANEL_SMARTDEBUFF, nUI_Dashboard.Anchor );
plugin.active   = true;

---------------------------------------------------
-- [v1.01.00] Validate Addon is loaded
-- [v1.01.01] Activate addon based on class before being based on the addon being loaded
---------------------------------------------------
local function onSmartDebuffEvent()
	if event == "VARIABLES_LOADED" then		

		-- If the addon exists make sure they are loaded
		if not IsAddOnLoaded( "SmartDebuff" ) then 
			if plugin.active then
				LoadAddOn( "SmartDebuff" );
			end
		end
		
		-- If required addon is loaded and available then activate the plugin
		if ( IsAddOnLoaded( "SmartDebuff" ) ) then 
			plugin.active = true;
		else
			plugin.active = false;
		end

	end	
end
plugin:SetScript( "OnEvent", onSmartDebuffEvent );
plugin:RegisterEvent( "VARIABLES_LOADED" );

---------------------------------------------------
-- [v1.01.00] Disable SmartDebuff Frame
---------------------------------------------------
disableSmartDebuff = function()
	local SmartDebuff = plugin.SmartDebuff;
	if SmartDebuff.saved_parent then
		nUI_Movers:lockFrame( SmartDebuff, false, nil );
		SmartDebuff:SetParent( SmartDebuff.saved_parent );
		SmartDebuff:SetBackdropBorderColor( SmartDebuff.border_color );
		SmartDebuff:SetBackdropColor( SmartDebuff.backdrop_color );			
	end
end

---------------------------------------------------
-- [v1.01.00] Enable the PallyPower Frame
---------------------------------------------------
enableSmartDebuff = function()
	local SmartDebuff = getglobal("SmartDebuffSF");
	plugin.SmartDebuff = SmartDebuff;
	
	-- Save some important information
	if not SmartDebuff.saved_parent then
		SmartDebuff.saved_parent   = SmartDebuff:GetParent();
		SmartDebuff.border_color   = SmartDebuff:GetBackdropBorderColor();
		SmartDebuff.backdrop_color = SmartDebuff:GetBackdropColor();		
	end
	
	-- Set the PallyPower Frame to fit into the info panel
	nUI_Movers:lockFrame( SmartDebuff, false, nil );
	SmartDebuff:SetParent( plugin.container );
	SmartDebuff:SetPoint( "TOPLEFT", plugin.container, "TOPLEFT", 10, -10 );
	--SmartDebuff:SetPoint( "BOTTOM", plugin.container, "BOTTOM", 0, 0 );
	SmartDebuff:SetPoint( "BOTTOMRIGHT", plugin.container, "BOTTOMRIGHT", -10, 10 );
	SmartDebuff:SetFrameStrata( plugin.container:GetFrameStrata() );
	SmartDebuff:SetFrameLevel( plugin.container:GetFrameLevel()+1 );
	SmartDebuff:SetBackdropBorderColor( 0, 0, 0, 0 );
	SmartDebuff:SetBackdropColor( 0, 0, 0, 0 );	
	if (SMARTDEBUFF_Options.ShowBackdrop) then
		SMARTDEBUFF_ToggleSFBackdrop();
	end
	--nUI_Movers:lockFrame( SmartDebuff, true, nil );

end


---------------------------------------------------
-- [v1.01.00] Resize the PallyPower Frame
---------------------------------------------------
resizeSmartDebuff = function(height,width)
	local SmartDebuff   = plugin.SmartDebuff;
	nUI_Movers:lockFrame( SmartDebuff, false, nil );
	SmartDebuff:SetWidth( width / 2 ); 
	SmartDebuff:SetHeight( height ); 
	--nUI_Movers:lockFrame( SmartDebuff, true, nil );
end

---------------------------------------------------
-- [v1.01.00] initPanel routine
---------------------------------------------------
plugin.initPanel = function( container, options )
	plugin.container = container;
	plugin.options   = options;
	if options and options.enabled then
		plugin.setEnabled( true );
	end
end

---------------------------------------------------
-- [v1.01.00] sizeChanged routine
---------------------------------------------------
plugin.sizeChanged = function( scale, height, width )
	local options  = plugin.options;
	plugin.scale = scale;
	
	resizeSmartDebuff(height,width);
end	

---------------------------------------------------
-- [v1.01.00] Validate Enable Status
---------------------------------------------------
plugin.setEnabled = function( enabled )
	if plugin.enabled ~= enabled then
		plugin.enabled = enabled;
		if not enabled then
			disableSmartDebuff();
		else
			enableSmartDebuff();
		end				
	end			
end

---------------------------------------------------
-- [v1.01.00] setSelected routine
---------------------------------------------------
plugin.setSelected = function( selected )
	if selected ~= plugin.selected then
		plugin.selected = selected;
		if selected then
		else
		end
	end
end
